workerCallbackBuilder function
Builder
workerCallbackBuilder(
- BuilderOptions options
Creates the WorkerCallbackGenerator builder registered in build.yaml.
Generates a .g.dart part file for every Dart library that contains
top-level functions annotated with @WorkerCallback.
This function is the entry point invoked by build_runner — it is not
called directly by application code.
Implementation
Builder workerCallbackBuilder(BuilderOptions options) =>
SharedPartBuilder([WorkerCallbackGenerator()], 'worker_callback');